Module: Iev
- Defined in:
- lib/iev/cli.rb,
lib/iev.rb,
lib/iev/cli/ui.rb,
lib/iev/config.rb,
lib/iev/scraper.rb,
lib/iev/version.rb,
lib/iev/exporter.rb,
lib/iev/profiler.rb,
lib/iev/converter.rb,
lib/iev/db_writer.rb,
lib/iev/utilities.rb,
lib/iev/relaton_db.rb,
lib/iev/cli/command.rb,
lib/iev/data_source.rb,
lib/iev/iso_639_code.rb,
lib/iev/term_builder.rb,
lib/iev/source_parser.rb,
lib/iev/data_conversions.rb,
lib/iev/term_attrs_parser.rb,
lib/iev/cli/command_helper.rb,
lib/iev/scraper/page_parser.rb,
lib/iev/supersession_parser.rb,
lib/iev/converter/mathml_to_asciimath.rb
Overview
© Copyright 2020 Ribose Inc.
Defined Under Namespace
Modules: Cli, Converter, DataConversions, DataSource, Utilities Classes: Config, DbWriter, Exporter, Iso639Code, Profiler, RelatonDb, Scraper, SourceParser, SupersessionParser, TermAttrsParser, TermBuilder
Constant Summary collapse
- VERSION =
"0.4.2"
Class Method Summary collapse
- .config ⇒ Object
- .configure {|config| ... } ⇒ Object
-
.fetch_concept(code) ⇒ Hash
Fetch full concept data (all languages) for a given IEV code.
-
.fetch_term(code, lang) ⇒ Hash?
Fetch localized term data for a given IEV code and language.
-
.get(code, lang) ⇒ String?
Fetch term designation from IEV data.
- .reset_config! ⇒ Object
-
.scrape_concept(code) ⇒ Hash?
Scrape concept data from Electropedia for a given IEV code.
Class Method Details
.configure {|config| ... } ⇒ Object
23 24 25 |
# File 'lib/iev/config.rb', line 23 def configure yield(config) if block_given? end |
.fetch_concept(code) ⇒ Hash
Fetch full concept data (all languages) for a given IEV code.
61 62 63 |
# File 'lib/iev.rb', line 61 def self.fetch_concept(code) DataSource.fetch_concept(code) end |
.fetch_term(code, lang) ⇒ Hash?
Fetch localized term data for a given IEV code and language.
71 72 73 |
# File 'lib/iev.rb', line 71 def self.fetch_term(code, lang) DataSource.fetch_term(code, lang) end |
.get(code, lang) ⇒ String?
Fetch term designation from IEV data.
50 51 52 53 54 |
# File 'lib/iev.rb', line 50 def self.get(code, lang) DataSource.fetch_term_designation(code, lang) rescue DataSource::NotFoundError nil end |
.reset_config! ⇒ Object
27 28 29 |
# File 'lib/iev/config.rb', line 27 def reset_config! @config = nil end |
.scrape_concept(code) ⇒ Hash?
Scrape concept data from Electropedia for a given IEV code. Uses Ferrum (headless Chrome) to handle AWS WAF challenge.
80 81 82 |
# File 'lib/iev.rb', line 80 def self.scrape_concept(code) Scraper.new.fetch_concept(code) end |